==> equity-base-0.5.2-RELEASE-sources.jar: com/rocogz/syy/equity/dto/equity/batchDistributionApply/UnReceiveDetailDto.java <==
package com.rocogz.syy.equity.dto.equity.batchDistributionApply;

import com.rocogz.syy.common.entity.IdEntity;
import lombok.Data;

import java.time.LocalDateTime;

/**
 * <dl>
 * <dd>Description: 未领取的申请单清单 dto</dd>
 * <dd>Company: 广州大诚若谷信息技术有限公司</dd>
 * <dd>@date：2021-02-23 11:31:22</dd>
 * <dd>@author：Andy</dd>
 * </dl>
 */
@Data
public class UnReceiveDetailDto extends IdEntity {

    /**
     * 发放主体
     */
    private String sourceName;

    /**
     * 申请单编号
     */
    private String applyNo;

    /**
     * 清单编号
     */
    private String applyDetailCode;

    /**
     * 手机号
     */
    private String mobile;

    /**
     * 证件类型
     */
    private String idType;

    /**
     * 证件号码
     */
    private String idCard;

    /**
     * 优惠券编号
     */
    private String couponCode;

    /**
     * 优惠券名称
     */
    private String couponName;

    /**
     * 权益发放时间
     */
    private LocalDateTime grantTime;

    /**
     * 生效日期
     */
    private LocalDateTime effectiveDate;

    /**
     * 失效日期
     */
    private LocalDateTime invalidDate;

    /**
     * 发放张数
     */
    private Integer quantity;

    /**
     * 车牌号
     */
    private String licenseNo;

    /**
     * 保单号
     */
    private String policyNo;

    /**
     * 姓名
     */
    private String name;

    /**
     * 平台产品编号
     */
    private String platformProductCode;

    /**
     * 客户产品编号
     */
    private String customerProductCode;

    /**
     * 代理商产品编号
     */
    private String agentProductCode;

    /**
     * 发放规则编号
     */
    private String grantRuleCode;

    /**
     * 领取规则编号
     */
    private String receiveRuleCode;

    /**
     * 单位金额
     */
    private String unitFaceValue;

    /**
     * 团队编号
     */
    private String teamCode;

    /**
     * 代理商编号
     */
    private String agentCode;

    /**
     * 客户编号
     */
    private String customerCode;

}

==> equity-base-0.5.22-RELEASE-sources.jar: com/rocogz/syy/equity/dto/equity/batchDistributionApply/UnReceiveDetailDto.java <==
package com.rocogz.syy.equity.dto.equity.batchDistributionApply;

import com.rocogz.syy.common.entity.IdEntity;
import lombok.Data;

import java.math.BigDecimal;
import java.time.LocalDateTime;

/**
 * <dl>
 * <dd>Description: 未领取的申请单清单 dto</dd>
 * <dd>Company: 广州大诚若谷信息技术有限公司</dd>
 * <dd>@date：2021-02-23 11:31:22</dd>
 * <dd>@author：Andy</dd>
 * </dl>
 */
@Data
public class UnReceiveDetailDto extends IdEntity {

    /**
     * 发放主体
     */
    private String sourceName;

    /**
     * 申请单编号
     */
    private String applyNo;

    /**
     * 清单编号
     */
    private String applyDetailCode;

    /**
     * 手机号
     */
    private String mobile;

    /**
     * 证件类型
     */
    private String idType;

    /**
     * 证件号码
     */
    private String idCard;

    /**
     * 优惠券编号
     */
    private String couponCode;

    /**
     * 优惠券名称
     */
    private String couponName;

    /**
     * 权益发放时间
     */
    private LocalDateTime grantTime;

    /**
     * 生效日期
     */
    private LocalDateTime effectiveDate;

    /**
     * 失效日期
     */
    private LocalDateTime invalidDate;

    /**
     * 发放张数
     */
    private Integer quantity;

    /**
     * 车牌号
     */
    private String licenseNo;

    /**
     * 保单号
     */
    private String policyNo;

    /**
     * 姓名
     */
    private String name;

    /**
     * 平台产品编号
     */
    private String platformProductCode;

    /**
     * 客户产品编号
     */
    private String customerProductCode;

    /**
     * 代理商产品编号
     */
    private String agentProductCode;

    /**
     * 发放规则编号
     */
    private String grantRuleCode;

    /**
     * 领取规则编号
     */
    private String receiveRuleCode;

    /**
     * 单位金额
     */
    private BigDecimal unitFaceValue;

    /**
     * 团队编号
     */
    private String teamCode;

    /**
     * 代理商编号
     */
    private String agentCode;

    /**
     * 客户编号
     */
    private String customerCode;

    /**
     * 申请人手机号
     */
    private String createUserMobile;

}
